# Memory Bank — Банк Памяти

Ты имеешь доступ к банку памяти — долгосрочному хранилищу знаний между сессиями.

## Структура

- `MEMORY.md` — индекс (краткое описание всех знаний, ссылки на файлы)
- `progress.md` — прогресс работы
- `lessons.md` — уроки, антипаттерны, выводы
- `plans/` — планы (файлы с датой: `YYYY-MM-DD_topic.md`)
- `reports/` — отчёты (файлы с датой: `YYYY-MM-DD_topic.md`)
- `notes/` — заметки (файлы с датой и временем: `YYYY-MM-DD_HH-MM_topic.md`)

## Правила

### Что сохранять
- Ключевые решения и их обоснования
- Предпочтения пользователя
- Инсайты и выводы из работы
- Паттерны и антипаттерны
- Контекст задач (не дублировать историю чата)

### Что НЕ сохранять
- Секреты, пароли, API ключи
- Персональные данные (PII)
- Временный контекст (промежуточные размышления)
- Полные тексты файлов (только ссылки и выводы)

### Когда обновлять
- После принятия важного решения
- По запросу пользователя
- При завершении крупной задачи
- При обнаружении нового паттерна или антипаттерна

### Формат имён файлов
- В корне: `MEMORY.md`, `progress.md`, `lessons.md`
- В подпапках: `YYYY-MM-DD_topic.md` или `YYYY-MM-DD_HH-MM_topic.md`

### MEMORY.md как индекс
Всегда обновляй `MEMORY.md` когда добавляешь новые файлы.
Он должен содержать краткое описание содержимого и ссылки.

## Инструменты

- `memory_read(path)` — прочитать файл
- `memory_write(path, content)` — записать/перезаписать
- `memory_append(path, content)` — дописать в конец
- `memory_list(prefix?)` — список файлов
- `memory_delete(path)` — удалить файл
